@@ -17,28 +17,28 @@ use Vote::Count::Matrix;
 
 no warnings 'experimental';
 
-our $VERSION='1.212';
+our $VERSION='1.213';
 
 =head1 NAME
 
-Vote::Count
+Vote::Count - a tool kit for preferential ballots
 
-=head1 VERSION 1.212
+=head1 VERSION 1.213
 
-=head2 A Toolkit for determining the outcome of Preferential Ballots.
+=head2 A Toolkit for Resolving Preferential Ballots.
 
-Vote::Count a Toolkit for implementing multiple voting systems, allowing a wide range of method options. Vote::Count provides a lot of options to facilitate writing code to match your election rules.
+Vote::Count provides a combination of methods and variations for conducting elections and studying different methods of resolving preferential ballots.
 
 =head1 DOCUMENTATION
 
+=head2 L<OVERVIEW|Overview>
+
+An overview of Preferential Voting and an introduction to Vote::Count. Read this document first.
+
 =head2 L<COMMON|Vote::Count::Common>
 
 The core methods of Vote::Count are documented in this Module.
 
-=head2 L<OVERVIEW|Overview>
-
-An overview of Preferential Voting and introduction to Vote::Count.
-
 =head2 L<CATALOG|Catalog>
 
 Catalog of Preferential Voting Methods implemented by Vote::Count and the Modules providing them.
@@ -107,7 +107,7 @@ __PACKAGE__->meta->make_immutable;
 
 =item *
 
-L<Vote::Count>
+L<Vote::Count - a tool kit for preferential ballots>
 
 =item *
 
@@ -203,7 +203,7 @@ L<Vote::Count::Method::WIGM>
 
 =item *
 
-L<Vote::Count::MultiMember>
+L<Vote::Count::MultiMember - Overview of Multi Member elections and Vote::Count support for them.>
 
 =item *
 
@@ -271,7 +271,7 @@ This module is released under the GNU Public License Version 3. See license file
 
 SUPPORT
 
-This software is provided as is, per the terms of the GNU Public License. Professional Support, Validation and Customization services are available, please contact the Author for a quote.
+This software is provided as is, per the terms of the GNU Public License. Professional support and customisation services are available from the author.
 
 =cut
 
