@@ -20,7 +20,7 @@ use JSON::MaybeXS;
 use YAML::XS;
 # use Storable 3.15 'dclone';
 
-our $VERSION='1.212';
+our $VERSION='1.213';
 
 has 'Seats' => (
   is       => 'ro',
@@ -111,7 +111,6 @@ sub BUILD {
 
 CountAbandoned
 
-
 =cut
 
 sub CountAbandoned ($I) {
@@ -378,11 +377,11 @@ sub SetQuota ($I, $style='droop') {
 
 Vote::Count::Charge
 
-=head1 VERSION 1.212
+=head1 VERSION 1.213
 
 =cut
 
-# ABSTRACT: Vote::Charge implementation of STV.
+# ABSTRACT: Vote::Charge - implementation of STV.
 
 =pod
 
@@ -446,6 +445,8 @@ elected and pending:
 
 Elected and Pending choices are removed from the Active Set, but Pending choices are not yet considered elected. The Pending state is available to hold newly elected choices for a method that will not immediately complete processing their election.
 
+=back
+
 =head3 GetChoiceStatus
 
 When called with the argument of a Choice, returns a hashref with the keys 'state' and 'votes'. When called without argument returns a hashref with the Choices as keys, and the values a hashref with the 'state' and 'votes' keys.
@@ -546,5 +547,9 @@ LICENSE
 
 This module is released under the GNU Public License Version 3. See license file for details. For more information on this license visit L<http://fsf.org>.
 
+SUPPORT
+
+This software is provided as is, per the terms of the GNU Public License. Professional support and customisation services are available from the author.
+
 =cut
 
