@@ -10,13 +10,13 @@ use Moose::Role;
 no warnings 'experimental';
 use Path::Tiny 0.108;
 
-our $VERSION='1.212';
+our $VERSION='1.213';
 
 =head1 NAME
 
 Vote::Count::Log
 
-=head1 VERSION 1.212
+=head1 VERSION 1.213
 
 =cut
 
@@ -46,10 +46,20 @@ Sets the Base portion of the logfile names, but only if LogPath is specified. Th
 
 Write the logs appending '.brief', '.full', and '.debug' for the three logs where brief is a summary written with the logt (log terse) method, the full transcript log written with logv, and finally the debug log written with logd. Each higher log level captures all events of the lower log levels.
 
+Logged events are not written until WriteLog is called. A fatal runtime error, would prevent execution of a writelog at the end of the script. If you need to see the logs when your program is crashing, set the Debug Flag to write the events as warnings to STDERR while the script is running.
+
 =head1 Logging Events
 
 When logging from your methods, use logt for events that produce a summary, use logv for events that should be in the full transcript such as round counts, and finally debug is for events that may be helpful in debugging but which should not be in the transcript. Events written to logt will be included in the verbose log and all events in the verbose log will be in the debug log.
 
+=head2 logt
+
+Record message to the terse (.brief)
+
+=head2 logv
+
+=head2 logd
+
 =head1 Debug Flag
 
 When the debug flag is logx methods will also emit the event as a warning (STDERR). The Debug Flag defaults to off (0), but can be explicitly set via the new method of a Vote::Count object, or toggled by passing 0 or 1 via the Debug Method.
@@ -154,5 +164,9 @@ LICENSE
 
 This module is released under the GNU Public License Version 3. See license file for details. For more information on this license visit L<http://fsf.org>.
 
+SUPPORT
+
+This software is provided as is, per the terms of the GNU Public License. Professional support and customisation services are available from the author.
+
 =cut
 
