@@ -2,6 +2,8 @@ package Vote::Count::ReadBallots;
 
 use 5.024;
 use feature qw/postderef signatures/;
+use strict;
+use warnings;
 no warnings qw/experimental/;
 use Path::Tiny 0.108;
 use Carp;
@@ -11,13 +13,13 @@ use YAML::XS;
 
 # ABSTRACT: Read Ballots for Vote::Count. Toolkit for vote counting.
 
-our $VERSION='1.212';
+our $VERSION='1.213';
 
 =head1 NAME
 
 Vote::Count::ReadBallots
 
-=head1 VERSION 1.212
+=head1 VERSION 1.213
 
 =head1 SYNOPSIS
 
@@ -246,5 +248,9 @@ LICENSE
 
 This module is released under the GNU Public License Version 3. See license file for details. For more information on this license visit L<http://fsf.org>.
 
+SUPPORT
+
+This software is provided as is, per the terms of the GNU Public License. Professional support and customisation services are available from the author.
+
 =cut
 
