@@ -1,6 +1,8 @@
 package Vote::Count::Start;
 
 use 5.024;
+use strict;
+use warnings;
 use feature qw/postderef signatures/;
 no warnings qw/experimental/;
 use Path::Tiny 0.108;
@@ -11,13 +13,13 @@ use Try::Tiny;
 use Vote::Count;
 use Vote::Count::ReadBallots 'read_ballots';
 
-our $VERSION='1.212';
+our $VERSION='1.213';
 
 =head1 NAME
 
 Vote::Count::Start
 
-=head1 VERSION 1.212
+=head1 VERSION 1.213
 
 =cut
 
@@ -154,7 +156,7 @@ sub _do_approval ( $Election ) {
 
 sub _do_borda ( $Election ) {
   my $Borda = $Election->Approval();
-  $Election->logv( "\Borda Count", $Borda->RankTable(), );
+  $Election->logv( "Borda Count", $Borda->RankTable(), );
   my $AWinner = $Borda->Leader();
   if ( $AWinner->{'winner'} ) {
     $Election->logt( "Borda Winner: " . $AWinner->{'winner'}, '' );
@@ -234,5 +236,9 @@ LICENSE
 
 This module is released under the GNU Public License Version 3. See license file for details. For more information on this license visit L<http://fsf.org>.
 
+SUPPORT
+
+This software is provided as is, per the terms of the GNU Public License. Professional support and customisation services are available from the author.
+
 =cut
 
